{
Client Access Objects 1.5

caoDatabaseDB2 component

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

The cwbDatabaseDB2 automation object is used for managing database files on an
AS/400 system.  For example, you can create, copy, delete, and override files.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

unit caoDatabaseDB2;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  caoErrorMessage, caoDatabaseConnection,

  // Import type library "Client Access Object Library" before installing.

  Cwbautsv_TLB;

type

  // caoDatabaseDB2 exception object

  EcaoDatabaseDB2 = class(Exception);

  TcaoDefaultCreateAuthority = (
    caodbSetLibraryCreateAuthorityC,
    caodbSetAllAuthorityC,
    caodbSetChangeAuthorityC,
    caodbSetExcludeAuthorityC,
    caodbSetUseAuthorityC);

  TcaoDefaultDuplicateAuthority = (
    caodbSetLibraryCreateAuthorityD,
    caodbSetAllAuthorityD,
    caodbSetChangeAuthorityD,
    caodbSetExcludeAuthorityD,
    caodbSetUseAuthorityD,
    caodbSetSameAuthorityD);

  TcaoDatabaseDB2 = class(TComponent)
  private
    { Private declarations }
    FReturnCode: integer;
    FSetupCalled: boolean;
    FdefaultMaximumMembers: ShortInt;
    FdefaultMemberText: WideString;
    FdefaultRecordLength: Integer;
    FdefaultCreateAuthority: TcaoDefaultCreateAuthority;
    FdefaultDuplicateAuthority: TcaoDefaultDuplicateAuthority;
    FdefaultCreateFileText: WideString;
    FdefaultDuplicateFileText: WideString;
    FdefaultCreateMemberName: WideString;
    FcwbDatabaseDB2: cwbDatabaseDB2;
    FcaoErrorMessage: TcaoErrorMessage;
    FcaoDatabaseConnection: TcaoDatabaseConnection;
    function GetDefaultMaximumMembers: ShortInt;
    procedure SetDefaultMaximumMembers(MaxMbr: ShortInt);
    function GetDefaultMemberText: WideString;
    procedure SetDefaultMemberText(MbrTxt: WideString);
    function GetDefaultRecordLength: integer;
    procedure SetDefaultRecordLength(RecLen: integer);
    function GetDefaultCreateAuthority: TcaoDefaultCreateAuthority;
    procedure SetDefaultCreateAuthority(CrtAut: TcaoDefaultCreateAuthority);
    function GetDefaultDuplicateAuthority: TcaoDefaultDuplicateAuthority;
    procedure SetDefaultDuplicateAuthority(DupAut: TcaoDefaultDuplicateAuthority);
    function GetDefaultCreateFileText: WideString;
    procedure SetDefaultCreateFileText(FilTxt: WideString);
    function GetDefaultDuplicateFileText: WideString;
    procedure SetDefaultDuplicateFileText(DupTxt: WideString);
    function GetDefaultCreateMemberName: WideString;
    procedure SetDefaultCreateMemberName(MbrNam: WideString);
  protected
    { Protected declarations }
    function ResultCodeText: string; virtual;
    function GetErrMsg: string; virtual;
    procedure Notification(AComponent: TComponent;
      Operation: TOperation); override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure Setup; virtual;
    procedure GetHostErrInfo(var errorClass: Smallint; var errorCode: Integer; var messageID: WideString; var message1: WideString; var message2: WideString); virtual;
    procedure AddLibraryToList(const libraryName: WideString; libraryPosition: Smallint); virtual;
    procedure AddMember(const libraryName, fileName, memberName: WideString); virtual;
    procedure ClearMember(const libraryName, fileName, memberName: WideString); virtual;
    procedure CreateDuplicateFile(const libraryName, fileName, baseLibraryName, baseFileName: WideString; copyDataIndicator: WordBool); virtual;
    procedure CreateSourcePhysicalFile(const libraryName, fileName: WideString); virtual;
    procedure DeleteFile(const libraryName, fileName: WideString); virtual;
    procedure OverrideFile(const libraryName, fileName, memberName, newFileName: WideString); virtual;
    procedure RemoveMember(const libraryName, fileName, memberName: WideString); virtual;
    procedure RemoveOverride(const fileName: WideString); virtual;
    procedure ChangeConnection(connection: IDispatch); virtual;
  published
    { Published declarations }
    property ReturnCode: integer read FReturnCode default cwbOK;
    property defaultMaximumMembers: ShortInt read GetDefaultMaximumMembers write SetdefaultMaximumMembers default 0;
    property defaultMemberText: WideString read GetDefaultMemberText write SetDefaultMemberText;
    property defaultRecordLength: integer read GetDefaultRecordLength write SetDefaultRecordLength default 0;
    property defaultCreateAuthority: TcaoDefaultCreateAuthority read GetDefaultCreateAuthority write SetDefaultCreateAuthority default caodbSetLibraryCreateAuthorityC;
    property defaultDuplicateAuthority: TcaoDefaultDuplicateAuthority read GetDefaultDuplicateAuthority write SetdefaultDuplicateAuthority default caodbSetSameAuthorityD;
    property defaultCreateFileText: WideString read GetDefaultCreateFileText write SetDefaultCreateFileText;
    property defaultDuplicateFileText: WideString read GetDefaultDuplicateFileText write SetDefaultDuplicateFileText;
    property defaultCreateMemberName: WideString read GetDefaultCreateMemberName write SetDefaultCreateMemberName;
    property errorMessage: TcaoErrorMessage read FcaoErrorMessage write FcaoErrorMessage;
    property databaseConnection: TcaoDatabaseConnection read FcaoDatabaseConnection write FcaoDatabaseConnection;
    property OleObject: cwbDatabaseDB2 read FcwbDatabaseDB2;
  end;

implementation

{
Create OLE object and initilize properties.
}

constructor TcaoDatabaseDB2.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FcwbDatabaseDB2 := CocwbDatabaseDB2.Create;
  FSetupCalled := false;
  FdefaultMaximumMembers := 0;
  FdefaultMemberText := '';
  FdefaultRecordLength := 0;
  FdefaultCreateAuthority := caodbSetLibraryCreateAuthorityC;
  FdefaultDuplicateAuthority := caodbSetSameAuthorityD;
  FdefaultCreateFileText := '';
  FdefaultDuplicateFileText := '';
  FdefaultCreateMemberName := ''
end;

{
Return formatted result code text.
}

function TcaoDatabaseDB2.ResultCodeText: string;
begin
  Result := Format('Result code %d',[FReturnCode])
end;

{
Return error mesage or formatted result code text.
}

function TcaoDatabaseDB2.GetErrMsg: string;
var
  S: string;
  errorClass: Smallint;
  errorCode: Integer;
  messageID: WideString;
  message1: WideString;
  message2: WideString;
  CauseStr: string;
  RecoveryStr: string;
  RecoveryPos: integer;
begin
  S := FcaoErrorMessage.GetErrMsg;
  if S <> '' then
  begin
    GetHostErrInfo(errorClass,errorCode,messageID,message1,message2);
    RecoveryPos := Pos('Recovery',message2);
    if RecoveryPos > 0 then
    begin
      CauseStr := Copy(message2,1,RecoveryPos-1);
      RecoveryStr := Copy(message2,RecoveryPos,Length(message2)-RecoveryPos)
    end
    else
    begin
      CauseStr := message2;
      RecoveryStr := '';
    end;
    S := Format('%s class: %d, code: %d, message ID: %s, %s'#10#10'%s'#10#10'%s',
    [S,errorClass,errorCode,messageID,message1,CauseStr,RecoveryStr])
  end
  else
    S := ResultCodeText;
  Result := S
end;

{
This property specifies the maximum number of members a file may have when is
it created with the cwbdbCreateSourcePhysicalFile method.  If this property is
not set, there will be no maximum.  This is a read/write property.

Get OLE property defaultMaximumMembers if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultMaximumMembers: ShortInt;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultMaximumMembers
  else
    Result := FdefaultMaximumMembers
end;

{
Set OLE property defaultMaximumMembers if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultMaximumMembers(MaxMbr: ShortInt);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultMaximumMembers := MaxMbr
  else
    FdefaultMaximumMembers := MaxMbr
end;

{
This property specifies the text description to be associated with a file
member when it is created using either the cwbdbAddMember or
cwbdbCreateSourcePhysicalFile methods.  If this property is not set, the member
text will be blank.  This is a read/write property.

Get OLE property defaultMemberText if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultMemberText: WideString;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultMemberText
  else
    Result := FdefaultMemberText
end;

{
Set OLE property defaultMemberText if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseDB2.SetDefaultMemberText(MbrTxt: WideString);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultMemberText := MbrTxt
  else
    FdefaultMemberText := MbrTxt
end;

{
This property specifies the record length to be used when creating a file with
the cwbdbCreateSourcePhysicalFile method.  Possible values are 1 through 32768.
If this property is not set, a record length of 92 is used.  This is a
read/write property.

Get OLE property defaultRecordLength if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultRecordLength: integer;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultRecordLength
  else
    Result := FdefaultRecordLength
end;

{
Set OLE property defaultRecordLength if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultRecordLength(RecLen: integer);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultRecordLength := RecLen
  else
    FdefaultRecordLength := RecLen
end;

{
This property defines the public authority assigned to a file when it is
created with the cwbdbCreateSourcePhysicalFile method.  Possible values are:

cwbdbSetLibraryCreateAuthority,
cwbdbSetAllAuthority
cwbdbSetChangeAuthority
cwbdbSetExcludeAuthority
cwbdbSetUseAuthority.

If this property is not set, cwbdbSetLibraryCreateAuthority is used.  This is a
read/write property.

Get OLE property defaultCreateAuthority if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultCreateAuthority: TcaoDefaultCreateAuthority;
begin
  if FSetupCalled then
    case FcwbDatabaseDB2.defaultCreateAuthority of
      cwbdbSetLibraryCreateAuthority:
        Result := caodbSetLibraryCreateAuthorityC;
      cwbdbSetAllAuthority:
        Result := caodbSetAllAuthorityC;
      cwbdbSetChangeAuthority:
        Result := caodbSetChangeAuthorityC;
      cwbdbSetExcludeAuthority:
        Result := caodbSetExcludeAuthorityC;
      cwbdbSetUseAuthority:
        Result := caodbSetUseAuthorityC
      else
        Result := caodbSetLibraryCreateAuthorityC
    end
  else
    Result := FdefaultCreateAuthority
end;

{
Set OLE property defaultCreateAuthority if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultCreateAuthority(CrtAut: TcaoDefaultCreateAuthority);
begin
  if FSetupCalled then
    case CrtAut of
      caodbSetLibraryCreateAuthorityC:
        FcwbDatabaseDB2.defaultCreateAuthority := cwbdbSetLibraryCreateAuthority;
      caodbSetAllAuthorityC:
        FcwbDatabaseDB2.defaultCreateAuthority := cwbdbSetAllAuthority;
      caodbSetChangeAuthorityC:
        FcwbDatabaseDB2.defaultCreateAuthority := cwbdbSetChangeAuthority;
      caodbSetExcludeAuthorityC:
        FcwbDatabaseDB2.defaultCreateAuthority := cwbdbSetExcludeAuthority;
      caodbSetUseAuthorityC:
        FcwbDatabaseDB2.defaultCreateAuthority := cwbdbSetUseAuthority
    end
  else
    FdefaultCreateAuthority := CrtAut
end;

{
This property defines the public authority assigned to a file when it is
created with the cwbdbCreateDuplicateFile method.  Possible values are:

cwbdbSetLibraryCreateAuthority
cwbdbSetAllAuthority
cwbdbSetChangeAuthority
cwbdbSetExcludeAuthority
cwbdbSetUseAuthority,
cwbdbSetSameAuthority

If this property is not set, the authority on the new file will be the same
(cwbdbSetSameAuthority) as the authority of the file to duplicate.  This is a
read/write property.

Get OLE property defaultDuplicateAuthority if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultDuplicateAuthority: TcaoDefaultDuplicateAuthority;
begin
  if FSetupCalled then
    case FcwbDatabaseDB2.defaultDuplicateAuthority of
      cwbdbSetLibraryCreateAuthority:
        Result := caodbSetLibraryCreateAuthorityD;
      cwbdbSetAllAuthority:
        Result := caodbSetAllAuthorityD;
      cwbdbSetChangeAuthority:
        Result := caodbSetChangeAuthorityD;
      cwbdbSetExcludeAuthority:
        Result := caodbSetExcludeAuthorityD;
      cwbdbSetUseAuthority:
        Result := caodbSetUseAuthorityD;
      cwbdbSetSameAuthority:
        Result := caodbSetSameAuthorityD
      else
        Result := caodbSetSameAuthorityD
    end
  else
    Result := FdefaultDuplicateAuthority
end;

{
Set OLE property defaultDuplicateAuthority if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultDuplicateAuthority(DupAut: TcaoDefaultDuplicateAuthority);
begin
  if FSetupCalled then
    case DupAut of
      caodbSetLibraryCreateAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetLibraryCreateAuthority;
      caodbSetAllAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetAllAuthority;
      caodbSetChangeAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetChangeAuthority;
      caodbSetExcludeAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetExcludeAuthority;
      caodbSetUseAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetUseAuthority;
      caodbSetSameAuthorityD:
        FcwbDatabaseDB2.defaultDuplicateAuthority := cwbdbSetSameAuthority
    end
  else
    FdefaultDuplicateAuthority := DupAut
end;

{
This property specifies the text description to be associated with a file when
it is created with the cwbdbCreateSourcePhysicalFile method.  If this property
is not set, the file text will be blank.  This is a read/write property.

Get OLE property defaultCreateFileText if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultCreateFileText: WideString;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultCreateFileText
  else
    Result := FdefaultCreateFileText
end;

{
Set OLE property defaultCreateFileText if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultCreateFileText(FilTxt: WideString);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultCreateFileText := FilTxt
  else
    FdefaultCreateFileText := FilTxt
end;

{
This property specifies the text description to be associated with a file when
it is created with the cwbdbCreateDuplicateFile method.  If this property is
not set, the file text for the new file will be the same as the file text of
the file to duplicate.  This is a read/write property.

Get OLE property defaultDuplicateFileText if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultDuplicateFileText: WideString;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultDuplicateFileText
  else
    Result := FdefaultDuplicateFileText
end;

{
Set OLE property defaultDuplicateFileText if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultDuplicateFileText(DupTxt: WideString);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultDuplicateFileText := DupTxt
  else
    FdefaultDuplicateFileText := DupTxt
end;

{
Get OLE property defaultCreateMemberName if setup was called.  Otherwise, get
private variable.
}

function TcaoDatabaseDB2.GetDefaultCreateMemberName: WideString;
begin
  if FSetupCalled then
    Result := FcwbDatabaseDB2.defaultCreateMemberName
  else
    Result := FdefaultCreateMemberName
end;

{
Set OLE property defaultCreateMemberName if setup was called. Otherwise, set
private variable.
}

procedure TcaoDatabaseDB2.SetDefaultCreateMemberName(MbrNam: WideString);
begin
  if FSetupCalled then
    FcwbDatabaseDB2.defaultCreateMemberName := MbrNam
  else
    FdefaultCreateMemberName := MbrNam
end;

{
Handle caoErrorMessage or caoDatabaseConnection component being removed.
}

procedure TcaoDatabaseDB2.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if Operation = opRemove then
  begin
    if AComponent = FcaoErrorMessage then
      FcaoErrorMessage := nil
    else
      if AComponent = FcaoDatabaseConnection then
        FcaoDatabaseConnection := nil
  end
end;

{
This method initializes the object.  It must be called before any other method
or before accessing any of the objects properties.
}

procedure TcaoDatabaseDB2.Setup;
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbSetup(
  FcaoDatabaseConnection.OleObject,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(ResultCodeText);
  FSetupCalled := true;
  // Set OLE properties from variables
  SetDefaultMaximumMembers(FdefaultMaximumMembers);
  SetDefaultMemberText(FdefaultMemberText);
  SetDefaultRecordLength(FdefaultRecordLength);
  SetdefaultCreateAuthority(FdefaultCreateAuthority);
  SetDefaultDuplicateAuthority(FdefaultDuplicateAuthority);
  SetDefaultCreateFileText(FdefaultCreateFileText);
  SetDefaultDuplicateFileText(FdefaultDuplicateFileText);
  SetDefaultCreateMemberName(FdefaultCreateMemberName)
end;

{
This method returns any host error information associated with the most recent
request.

Parameters:
errorClass - Pointer to Short Integer
Specifies a buffer where the error class will be stored.  This class indicates
which database server module encountered an error.  Possible values are:

0 - no error
1 - SQL functional error
2 - SQL parameter error
3 - List functional error
4 - List parameter error
5 - DB2 functional error
6 - DB2 parameter error
7 - General server error
8 - User exit error

errorCode - Pointer to Long
Specifies a buffer where the return code from the server module will be stored.

messageID - Pointer to String
Provides a location to store the host message identifier.  (This should be
passed as a pointer to a BSTR.)

message1 - Pointer to String
Provides a location to store the first host message.  (This should be passed as
a pointer to a BSTR.)

message2 - Pointer to String
Provides a location to store the second host message identifier.  (This should
be passed as a pointer to a BSTR.)
}

procedure TcaoDatabaseDB2.GetHostErrInfo(var errorClass: Smallint; var errorCode: Integer; var messageID: WideString; var message1: WideString; var message2: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbGetHostErrInfo(errorClass,errorCode,
  messageID,message1,message2,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method adds a library to the AS/400 library list.

Parameters:

libraryName - String
Identifies the name of the library to be added to the library list.

libraryPosition - Short Integer
Identifes the position within the library list to add the library name.  Valid
values are:

	cwbdbAddLibraryToFront
	cwbdbAddLibraryToEnd
}

procedure TcaoDatabaseDB2.AddLibraryToList(const libraryName: WideString; libraryPosition: Smallint);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbAddLibraryToList(
  libraryName,libraryPosition,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method adds a member to a file on the AS/400.

Parameters:
libraryName - String
Identifies the library in which the file exists.
fileName - String
Identifes the file to contain the new member.
memberName - String
Identifies the name of the new member.

Before this method is called, the following property(ies) may be set:

defaultMemberText


After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.AddMember(const libraryName, fileName, memberName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbAddMember(
  libraryName,fileName,memberName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method clears the data from a member in an AS/400 file.

Parameters:
libraryName - String
Identifies the library in which the file exists.
fileName - String
Identifes the file which contains the member to clear.
memberName - String
Identifies the member to be cleared.

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.ClearMember(const libraryName, fileName, memberName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbClearMember(
  libraryName,fileName,memberName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method creates a file based on an existing file.

Parameters:

libraryName - String
Identifies the library to contain the new file.

fileName - String
Identifes the name of the new file.

baseLibraryName - String
Identifes the library containing the file to copy.

baseFileName - String
Identifies the file to copy.

copyDataIndicator - Boolean
Identifes whether the data from the base file is to be copied into the
duplicate file.  If true, data will be copied.

Before this method is called, the following property(ies) may be set:

defaultDuplicateAuthority
defaultDuplicateFileText


After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.CreateDuplicateFile(const libraryName, fileName, baseLibraryName, baseFileName: WideString; copyDataIndicator: WordBool);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbCreateDuplicateFile(
  libraryName,fileName,baseLibraryName,baseFileName,copyDataIndicator,
  FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method creates a source file on the AS/400.

Parameters:

libraryName - String
Identifies the library to contain the new file.

fileName - String
Identifes the name of the new file.

Before this method is called, the following property(ies) may be set:

defaultMaximumMembers
defaultMemberText
defaultRecordLength
defaultCreateAuthority
defaultCreateFileText
defaultCreateMemberName

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.CreateSourcePhysicalFile(const libraryName, fileName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbCreateSourcePhysicalFile(
  libraryName,fileName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method deletes a file from an AS/400.

Parameters:

libraryName - String
Identifies the library in which the file exists.

fileName - String
Identifes the file to be deleted.

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.DeleteFile(const libraryName, fileName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbDeleteFile(
  libraryName,fileName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method provides a way to use a different name for referencing a file or a
member.  This override can be removed by calling the cwbdbRemoveOverride
method.

Parameters:

libraryName - String
Identifies the library in which the file exists.

fileName - String
Identifes the file to be accessed.

memberName - String
Identifes the member to be accessed.

newFileName - String
Specifies the new file name to be used to refer to the file or member.

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.OverrideFile(const libraryName, fileName, memberName, newFileName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbOverrideFile(
  libraryName,fileName,memberName,newFileName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method removes a member from an AS/400 file.

Parameters:

libraryName - String
Identifies the library in which the file exists.

fileName - String
Identifes the file containing the member to remove.

memberName - String
Identifies the member to remove.

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.RemoveMember(const libraryName, fileName, memberName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbRemoveMember(
  libraryName,fileName,memberName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method stops overriding all references for a file name to a different file
or member.  To create a  file override, the cwbdbOverrideFile method can be
used.

Parameters:

fileName - String
Identifes the value specified for the newFileName parameter, when the
cwbdbOverrideFile method was called.

After this method is called, the following methods may be called to obtain the
results of the request:

cwbdbGetHostErrInfo
}

procedure TcaoDatabaseDB2.RemoveOverride(const fileName: WideString);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbRemoveOverride(
  fileName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

{
This method provides a way to switch which cwbDatabaseConnection object is used
for the catalog requests made by this object.

Parameters:

connection - Object
Identifies the new cwbDatabaseConnection object to be used for servicing
requests of this object.
}

procedure TcaoDatabaseDB2.ChangeConnection(connection: IDispatch);
begin
  FReturnCode := FcwbDatabaseDB2.cwbdbChangeConnection(
  connection,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseDB2.Create(GetErrMsg)
end;

end.
