{
Client Access Objects 1.5

Security APIs for Client Access/400 translated to Delphi. ANSI and UNICODE
functions included.

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

(********************************************************************)
(* Copyright = 5763-XA1 (C) Copyright IBM Corp 1994, 1996.          *)
(*  All rights reserved.                                            *)
(*  Licensed Material - Program property of IBM                     *)
(*  Refer to copyright instructions form number G120-2083.          *)
(********************************************************************)
(********************************************************************)
(*                                                                  *)
(* Module:                                                          *)
(*   CWBSY.H                                                        *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   It contains the declarations for the following API's:          *)
(*                                                                  *)
(*   cwbSY_CreateSecurityObj                                        *)
(*   cwbSY_DeleteSecurityObj                                        *)
(*                                                                  *)
(*   cwbSY_SetSys                                                   *)
(*   cwbSY_SetSysA                                                  *)
(*   cwbSY_SetSysW                                                  *)
(*                                                                  *)
(*   cwbSY_VerifyUserIDPwd                                          *)
(*   cwbSY_VerifyUserIDPwdA                                         *)
(*   cwbSY_VerifyUserIDPwdW                                         *)
(*   cwbSY_ChangePwd                                                *)
(*   cwbSY_ChangePwdA                                               *)
(*   cwbSY_ChangePwdW                                               *)
(*   cwbSY_GetUserID                                                *)
(*   cwbSY_GetUserIDA                                               *)
(*   cwbSY_GetUserIDW                                               *)
(*                                                                  *)
(*   cwbSY_Logon                                                    *)
(*                                                                  *)
(*   cwbSY_GetDateTimePwdExpires                                    *)
(*   cwbSY_GetFailedAttempts                                        *)
(*   cwbSY_GetDateTimeLastSignon                                    *)
(*   cwbSY_GetDateTimeCurrentSignon                                 *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   Link with CWBAPI.LIB import library.                           *)
(*   This module is to be used in conjunction with CWBSY.DLL.       *)
(*                                                                  *)
(*   The Security Function allows you to manage the Security of     *)
(*   your information through password control.  The Security APIs  *)
(*   allow you to:                                                  *)
(*     Verify your user ID and password on an AS/400 system         *)
(*     Change your password on an AS/400 system                     *)
(*     Retrieve information about your user ID, such as:            *)
(*     - Date and time your password will expire                    *)
(*     - Date and time of the last successful logon attempt         *)
(*     - Date and time of the current signon                        *)
(*     - Number of failed signon attempts                           *)
(*                                                                  *)
(*   In addition to the return codes listed for APIs additional     *)
(*   operating system specific return codes may also appear.  The   *)
(*   precise meaning of these return codes can be found in the      *)
(*   operating system manuals or relevant header files.             *)
(*                                                                  *)
(********************************************************************)

unit cwbsy;

interface

uses
  Windows, cwb, cwbsv;

type
  cwbSY_SecurityHandle = CWB_HANDLE;

(*********************************************************************)
(* DEFINES: for string lengths (includes room for terminating null   *)
(*********************************************************************)

const
  CWBSY_MAX_SYSTEM_NAME = 255+1;
  CWBSY_MAX_USER_ID = 10+1;
  CWBSY_MAX_PASSWORD = 10+1;

(*********************************************************************)
(* DEFINES: for date/time return values                              *)
(*********************************************************************)

  CWBSY_DATE_TIME_LEN = 8;

(*********************************************************************)
(* RETURN CODES: start at CWB_LAST+1 which is defined in CWB.H       *)
(*********************************************************************)

  CWBSY_START = CWB_LAST+1;

(*********************************************************************)
(* User ID does not exist.                                           *)
(*********************************************************************)

  CWBSY_UNKNOWN_USERID = CWBSY_START;

(*********************************************************************)
(* Password is not correct for specified user ID.                    *)
(*********************************************************************)

  CWBSY_WRONG_PASSWORD = CWBSY_START+2;

(*********************************************************************)
(* Password has expired.                                             *)
(*********************************************************************)

  CWBSY_PASSWORD_EXPIRED = CWBSY_START+3;

(*********************************************************************)
(* One or more characters in the password is not valid or the        *)
(* password is too long.                                             *)
(*********************************************************************)

  CWBSY_INVALID_PASSWORD = CWBSY_START+4;

(*********************************************************************)
(* A general security error occurred. The user profile does not      *)
(* have a password or the password validation program found an       *)
(* error in the password.                                            *)
(*********************************************************************)

  CWBSY_GENERAL_SECURITY_ERROR = CWBSY_START+7;

(*********************************************************************)
(* The AS/400 user profile is not valid.                             *)
(*********************************************************************)

  CWBSY_INVALID_PROFILE = CWBSY_START+9;

(*********************************************************************)
(* The AS/400 user profile (user ID) has been set to disabled.       *)
(*********************************************************************)

  CWBSY_USER_PROFILE_DISABLED = CWBSY_START+11;

(*********************************************************************)
(* The user canceled from the user ID/password prompt.               *)
(*********************************************************************)

  CWBSY_USER_CANCELLED = CWBSY_START+13;

(*********************************************************************)
(* One or more characters in the user ID is not valid or the         *)
(* user ID is too long.                                              *)
(*********************************************************************)

  CWBSY_INVALID_USERID = CWBSY_START+15;

(*********************************************************************)
(* The system specified is unknown.                                  *)
(*********************************************************************)

  CWBSY_UNKNOWN_SYSTEM = CWBSY_START+16;

(*********************************************************************)
(* The PC could not validate the AS/400 security server. This        *)
(* could indicate tampering with the IBM supplied security server    *)
(* program on the AS/400.                                            *)
(*********************************************************************)

  CWBSY_TP_NOT_VALID = CWBSY_START+19;

(*********************************************************************)
(* There is no user currently logged on for the specified system.    *)
(*********************************************************************)

  CWBSY_NOT_LOGGED_ON = CWBSY_START+22;

(*********************************************************************)
(* The system specified in the security object has not been          *)
(* configured.                                                       *)
(*********************************************************************)

  CWBSY_SYSTEM_NOT_CONFIGURED = CWBSY_START+25; {// @A1A}

(*********************************************************************)
(*   The user ID and password defined in the object has not yet      *)
(*   been verified. You must verify using cwbSY_verifyUserIDPwd      *)
(*   API.                                                            *)
(*********************************************************************)

  CWBSY_NOT_VERIFIED = CWBSY_START+26;

(*********************************************************************)
(* Internal error. Contact IBM Service.                              *)
(*********************************************************************)

  CWBSY_INTERNAL_ERROR = CWBSY_START+255;

(*********************************************************************)
(* Change password errors                                            *)
(*********************************************************************)

(*********************************************************************)
(* The new password contains too many characters. The maximum        *)
(* number of characters allowed is defined by the AS/400 system      *)
(* value, QPWDMAXLEN.                                                *)
(*********************************************************************)

  CWBSY_PWD_TOO_LONG = CWBSY_START+257;

(*********************************************************************)
(* The new password does not contain enough characters. The          *)
(* The minimum number of characters allowed is defined by the        *)
(* AS/400 system value, QPWDMINLEN.                                  *)
(*********************************************************************)

  CWBSY_PWD_TOO_SHORT = CWBSY_START+258;

(*********************************************************************)
(* The new password contains a character used more than once.        *)
(* The AS/400 configuration (system value QPWDLMTREP) does not       *)
(* allow passwords to contain a repeat character.                    *)
(*********************************************************************)

  CWBSY_PWD_REPEAT_CHARACTER = CWBSY_START+259;

(*********************************************************************)
(* The new password contains two numbers next to each other. The     *)
(* The AS/400 configuration (system value QPWDLMTAJC) does not       *)
(* allow passwords to contain consecutive digits.                    *)
(*********************************************************************)

  CWBSY_PWD_ADJACENT_DIGITS = CWBSY_START+260;

(*********************************************************************)
(* The new password contains a character repeated consecutively.     *)
(* The AS/400 configuration (system value QPWDLMTREP) does not       *)
(* allow a password to contain a character repeated consecutively.   *)
(*********************************************************************)

  CWBSY_PWD_CONSECUTIVE_CHARS = CWBSY_START+261;

(*********************************************************************)
(* The new password matches a previously used password. The          *)
(* AS/400 configuration (system value QPWDRQDDIF) requires new       *)
(* passwords to be different than any previous password.             *)
(*********************************************************************)

  CWBSY_PWD_PREVIOUSLY_USED = CWBSY_START+262;

(*********************************************************************)
(* The new password uses an installation disallowed character.       *)
(* AS/400 configuration (system value QPWDLMTCHR) restricts          *)
(* certain characters from being used in new passwords.              *)
(*********************************************************************)

  CWBSY_PWD_DISALLOWED_CHAR = CWBSY_START+263;

(*********************************************************************)
(* The new password must contain a number. The AS/400                *)
(* configuration (system value QPWDRQDDGT) requires new passwords    *)
(* contain one or more numeric digits.                               *)
(*********************************************************************)

  CWBSY_PWD_NEED_NUMERIC = CWBSY_START+264;

(*********************************************************************)
(* The new password matches an old password in one or more           *)
(* character positions. The AS/400 configuration (system value       *)
(* QPWDPOSDIF) does not allow the same character to be in the        *)
(* same position as a previous password.                             *)
(*********************************************************************)

  CWBSY_PWD_MATCHES_OLD = CWBSY_START+266;

(*********************************************************************)
(* The password was rejected                                         *)
(*********************************************************************)

  CWBSY_PWD_NOT_ALLOWED = CWBSY_START+267;

(*********************************************************************)
(* The password matches the user ID.                                 *)
(*********************************************************************)

  CWBSY_PWD_MATCHES_USERID = CWBSY_START+268;

(*********************************************************************)
(* The old password was created on a pre-V3 system which used a      *)
(* different encryption technique. Password must be changed          *)
(* manually on the AS/400.                                           *)
(*********************************************************************)

  CWBSY_PWD_PRE_V3 = CWBSY_START+269;

(*********************************************************************)
(* The next invalid will disable the user profile.                   *)
(*********************************************************************)

  CWBSY_LAST_INVALID_PASSWORD = CWBSY_START+270;

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_ChangePwd                                                *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Changes the password on the specified AS/400 system.           *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   const char * userID - input                                    *)
(*       A pointer to an ASCIIZ string which contains the user ID.  *)
(*       The maximum length is 10 bytes + 1 byte for the null       *)
(*       terminator.                                                *)
(*                                                                  *)
(*   const char * oldPassword - input                               *)
(*       A pointer to an ASCIIZ string which contains the current   *)
(*       password.  The maximum length is 10 bytes + 1 byte for the *)
(*       NULL terminator.                                           *)
(*                                                                  *)
(*   const char * newPassword - input                               *)
(*       A pointer to an ASCIIZ string which contains the new       *)
(*       password.  The maximum length is 10 bytes + 1 byte for the *)
(*       NULL terminator.                                           *)
(*                                                                  *)
(*   cwbSV_ErrHandle errorHandle - output                           *)
(*     Any returned messages will be written to this object.  It    *)
(*     is created with the cwbSV_CreateErrHandle API.  The          *)
(*     messages may be retrieved through the cwbSV_GetErrText API.  *)
(*     If the parameter is set to zero, no messages will be         *)
(*     retrieved.                                                   *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle supplied is           *)
(*                        not valid.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_COMMUNICATIONS_ERROR - A communication error occurred      *)
(*                              when attempting to contact the      *)
(*                              system.                             *)
(*   CWBSY_SYSTEM_NOT_CONFIGURED - The system has not been          *)
(*                                 configured.                      *)
(*   CWBSY_GENERAL_SECURITY_ERROR - A general security error        *)
(*                                  occurred.  The user profile     *)
(*                                  does not have a password or the *)
(*                                  password validation program     *)
(*                                  found an error in the password. *)
(*   CWBSY_INVALID_PASSWORD - One or more characters in the         *)
(*                            password is invalid or the password   *)
(*                            is too long.                          *)
(*   CWBSY_INVALID_USERID - One or more characters in the user ID   *)
(*                          is invalid or the user ID is too long.  *)
(*   CWBSY_UNKNOWN_USERID - The supplied user ID is not             *)
(*                          known to this system.                   *)
(*   CWBSY_WRONG_PASSWORD - Password is not correct.                *)
(*   CWBSY_USER_PROFILE_DISABLED - The user ID has been disabled.   *)
(*   CWBSY_PWD_TOO_LONG - New password longer than maximum          *)
(*                       accepted length.                           *)
(*   CWBSY_PWD_TOO_SHORT - New password shorter than minimum        *)
(*                        accepted length.                          *)
(*   CWBSY_PWD_REPEAT_CHARACTER - New password contains a character *)
(*                               used more than once.               *)
(*   CWBSY_PWD_ADJACENT_DIGITS - New password has adjacent digits.  *)
(*   CWBSY_PWD_CONSECUTIVE_CHARS - New password contains a character*)
(*                                repeated consecutively.           *)
(*   CWBSY_PWD_PREVIOUSLY_USED - New password was previously used.  *)
(*   CWBSY_PWD_DISALLOWED_CHAR - New password uses an installation  *)
(*                              disallowed character.               *)
(*   CWBSY_PWD_NEED_NUMERIC - New password must contain at          *)
(*                           least one numeric.                     *)
(*   CWBSY_PWD_MATCHES_OLD - New password matches old password      *)
(*                          in one or more character positions.     *)
(*   CWBSY_PWD_NOT_ALLOWED - New password exists in a dictionary of *)
(*                          disallowed passwords.                   *)
(*   CWBSY_PWD_MATCHES_USERID - New password matches the user ID.   *)
(*   CWBSY_PWD_PRE_V3 - The old password was created on a pre-V3    *)
(*                      system which used a different encryption    *)
(*                      technique.  Password must be changed        *)
(*                      manually on the AS/400.                     *)
(*   CWBSY_LAST_INVALID_PASSWORD - The next invalid password        *)
(*                                 will disable the user profile.   *)
(*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   *)
(*                           to allocate temporary buffer.          *)
(*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE *)
(*                                        characters have no        *)
(*                                        representation in the     *)
(*                                        codepage being used.      *)
(*   CWB_API_ERROR - General API failure.                           *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   The system name must be set prior to calling this API by using *)
(*   the cwbSY_SetSys API.                                          *)
(*                                                                  *)
(********************************************************************)

function cwbSY_ChangePwd(securityHandle: CWBSY_SECURITYHANDLE;
const userID: PChar;
const oldPassword: PChar;
const newPassword: PChar;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_ChangePwdA(securityHandle: CWBSY_SECURITYHANDLE;
var userID: AnsiString;
var oldPassword: AnsiString;
var newPassword: AnsiString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_ChangePwdW(securityHandle: CWBSY_SECURITYHANDLE;
var userID: WideString;
var oldPassword: WideString;
var newPassword: WideString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_CreateSecurityObj                                        *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Creates a security object.  When you are finished using the    *)
(*   object you should delete it using the cwbSY_DeleteSecurityObj  *)
(*   API.                                                           *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - output                   *)
(*        Pointer to a cwbSY_SecurityHandle.  If the create is      *)
(*        successful this will contain a handle to the newly        *)
(*        created security object.  This handle is required on the  *)
(*        other security APIs.                                      *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_NOT_ENOUGH_MEMORY - Not enough memory available to create  *)
(*                           object.                                *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_CreateSecurityObj(
var securityHandle: CWBSY_SECURITYHANDLE
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_DeleteSecurityObj                                        *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Deletes a security object.                                     *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_DeleteSecurityObj(
SecurityHandle: CWBSY_SECURITYHANDLE
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_GetDateTimeCurrentSignon                                 *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Retrieves the date and time of the current successful signon.  *)
(*   You must have successfully called cwbSY_verifyUserIDPwd        *)
(*   before using this API.                                         *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   unsigned char * lastSignonDateTime - output                    *)
(*       A pointer to 8 bytes which will contain the date and time  *)
(*       when the current signon occurred in this format:           *)
(*                                                                  *)
(*       Bytes     Content                                          *)
(*       --------  -----------------------------------------------  *)
(*       1 - 2     Year (Example: 1994 = 0x07CA)                    *)
(*       3         Month (January = 0x01)                           *)
(*       4         Day   (First day = 0x01;31st day = 0x1F)         *)
(*       5         Hour  (Midnight = 0x01;23rd hour = 0x17)         *)
(*       6         Minute (On the hour = 0x00; 59th minute = 0x3B)  *)
(*       7         Second (On the minute = 0x00; 59th second = 0x3B)*)
(*       8         One-hundredth of a second (on the second = 0x00; *)
(*                 maximum = 0x63)                                  *)
(*                                                                  *)
(*   Note: On a given day, the maximum time is 23 hours, 59         *)
(*         minutes, and 59.99 seconds.  Midnight is 0 hours, 0      *)
(*         minutes and 0.0 seconds on the following day.            *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWBSY_NOT_VERIFIED - The user ID and password defined in       *)
(*                        object has not been verified.  Make sure  *)
(*                        you have first called                     *)
(*                        cwbSY_verifyUserIDPwd before using        *)
(*                        this API.                                 *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_GetDateTimeCurrentSignon(
securityHandle: CWBSY_SECURITYHANDLE;
currentSignonDateTime: PChar
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_GetDateTimeLastSignon                                    *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Retrieves the date and time of the previous successful signon. *)
(*   You must have successfully called cwbSY_verifyUserIDPwd        *)
(*   before using this API.                                         *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   unsigned char * lastSignonDateTime - output                    *)
(*       A pointer to 8 bytes which will contain the date and time  *)
(*       of the last successful signon in the following format:     *)
(*                                                                  *)
(*       Bytes     Content                                          *)
(*       --------  -----------------------------------------------  *)
(*       1 - 2     Year (Example: 1994 = 0x07CA)                    *)
(*       3         Month (January = 0x01)                           *)
(*       4         Day   (First day = 0x01;31st day = 0x1F)         *)
(*       5         Hour  (Midnight = 0x01;23rd hour = 0x17)         *)
(*       6         Minute (On the hour = 0x00; 59th minute = 0x3B)  *)
(*       7         Second (On the minute = 0x00; 59th second = 0x3B)*)
(*       8         One-hundredth of a second (on the second = 0x00; *)
(*                 maximum = 0x63                                   *)
(*                                                                  *)
(*   Note: On a given day, the maximum time is 23 hours, 59         *)
(*         minutes, and 59.99 seconds.  Midnight is 0 hours, 0      *)
(*         minutes and 0.0 seconds on the following day.            *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWBSY_NOT_VERIFIED - The user ID and password defined in       *)
(*                        object has not been verified.  Make sure  *)
(*                        you have first called                     *)
(*                        cwbSY_verifyUserIDPwd before using        *)
(*                        this API.                                 *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_GetDateTimeLastSignon(
securityHandle: CWBSY_SECURITYHANDLE;
lastSignonDateTime: PChar
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_GetDateTimePwdExpires                                    *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Retrieves the date and time the password will expire for the   *)
(*   given system.  You must have successfully called               *)
(*   cwbSY_verifyUserIDPwd before using this API.                   *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   unsigned char * expirationDateTime - output                    *)
(*       A pointer to 8 bytes which will contain the date and time  *)
(*       the password expires in the following format:              *)
(*                                                                  *)
(*       Bytes     Content                                          *)
(*       --------  -----------------------------------------------  *)
(*       1 - 2     Year (Example: 1994 = 0x07CA)                    *)
(*       3         Month (January = 0x01)                           *)
(*       4         Day   (First day = 0x01;31st day = 0x1F)         *)
(*       5         Hour  (Midnight = 0x01;23rd hour = 0x17)         *)
(*       6         Minute (On the hour = 0x00; 59th minute = 0x3B)  *)
(*       7         Second (On the minute = 0x00; 59th second = 0x3B)*)
(*       8         One-hundredth of a second (on the second = 0x00; *)
(*                 maximum = 0x63)                                  *)
(*                                                                  *)
(*   Note: On a given day, the maximum time is 23 hours, 59         *)
(*         minutes, and 59.99 seconds.  Midnight is 0 hours, 0      *)
(*         minutes and 0.0 seconds on the following day.            *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWBSY_NOT_VERIFIED - The user ID and password defined in       *)
(*                        object has not been verified.  Make sure  *)
(*                        you have first called                     *)
(*                        cwbSY_verifyUserIDPwd before using        *)
(*                        this API.                                 *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_GetDateTimePwdExpires(
securityHandle: CWBSY_SECURITYHANDLE;
expirationDateTime: PChar
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_GetFailedAttempts                                        *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Retrieves the number of unsuccessful logon attempts.           *)
(*   You must have successfully called cwbSY_verifyUserIDPwd        *)
(*   before using this API.                                         *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   unsigned short * numberFailedAttempts - output                 *)
(*       A pointer to a short which will contain the number of      *)
(*       failed logon attempts.                                     *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWBSY_NOT_VERIFIED - The user ID and password defined in       *)
(*                        object has not been verified.  Make sure  *)
(*                        you have first called                     *)
(*                        cwbSY_verifyUserIDPwd before using        *)
(*                        this API.                                 *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_GetFailedAttempts(
securityHandle: CWBSY_SECURITYHANDLE;
numberFailedAttempts: PChar
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_GetUserID                                                *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   The API retrieves the currently logged on user ID for the      *)
(*   specified system.                                              *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   const char * systemName - input                                *)
(*       A pointer to an ASCIIZ string containing the name of the   *)
(*       AS/400 system.                                             *)
(*                                                                  *)
(*   char * userID - output                                         *)
(*       A pointer to an ASCIIZ string to receive the user ID.      *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWB_INVALID_POINTER - One of the pointers supplied as a        *)
(*                         parameter is not valid.                  *)
(*   CWBSY_SYSTEM_NOT_CONFIGURED - The system has not been          *)
(*                                 configured.                      *)
(*   CWBSY_NOT_LOGGED_ON - There is currently no user logged on     *)
(*                         for the specified system.                *)
(*   CWB_INVALID_PARAMETER - One of the parameters specified is     *)
(*                           invalid.                               *)
(*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   *)
(*                           to allocate temporary buffer.          *)
(*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE *)
(*                                        characters have no        *)
(*                                        representation in the     *)
(*                                        codepage being used.      *)
(*   CWB_API_ERROR - General API failure.                           *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_GetUserID(
securityHandle: CWBSY_SECURITYHANDLE;
const systemName: PChar;
userID: PChar
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_GetUserIDA(
securityHandle: CWBSY_SECURITYHANDLE;
const systemName: PChar;
UserID: PChar
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_GetUserIDW(
securityHandle: CWBSY_SECURITYHANDLE;
var systemName: WideString;
var userID: WideChar
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_Logon                                                    *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   This procedure prompts for and validates user ID and password. *)
(*   If they are valid, the information is stored and subsequent    *)
(*   sign-ons and requests for other functions are not prompted     *)
(*   for.                                                           *)
(*                                                                  *)
(*   A sign-on prompt may not be presented if the following are all *)
(*   true:                                                          *)
(*   - There is a default user ID configured for the system being   *)
(*     used (see cwbSY_setSys).                                     *)
(*   - A previous sign-on prompt was displayed where the default    *)
(*     user ID and password were used and the sign-on was           *)
(*     successful.                                                  *)
(*   In this case, the user ID and password are used again and no   *)
(*   prompt occurs.                                                 *)
(*                                                                  *)
(*   Note:  If the 'Enable caching of AS/400 passwords' option on   *)
(*          the Client Access tab of the Passwords control panel is *)
(*          not checked, you will be prompted to sign-on each time  *)
(*          the PC is restarted.  This is because the user ID and   *)
(*          password are not saved.                                 *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion                                 *)
(*   CWB_INVALID_HANDLE  - The security handle is not valid.        *)
(*   CWBSY_PASSWORD_EXPIRED - Password has expired.                 *)
(*   CWBSY_USER_CANCELLED - The user cancelled the user ID and      *)
(*                          password prompt.                        *)
(*   CWB_COMMUNICATIONS_ERROR - A communication error occurred      *)
(*                              when attempting to contact the      *)
(*                              system.                             *)
(*   CWBSY_SYSTEM_NOT_CONFIGURED - The system has not been          *)
(*                                 configured.                      *)
(*   CWBSY_LAST_INVALID_PASSWORD - The next invalid password        *)
(*                                 will disable the user profile.   *)
(*   CWBSY_USER_PROFILE_DISABLED - The user ID has been disabled.   *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   The system name must be set prior to calling this API by using *)
(*   the cwbSY_SetSys API.                                          *)
(*                                                                  *)
(********************************************************************)

function cwbSY_Logon(
securityHandle: CWBSY_SECURITYHANDLE
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_SetSys                                                   *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   The API sets the name of the system in the specified security  *)
(*   object.  No validation of the system name is done.  The system *)
(*   name is checked when the user ID and password are verified     *)
(*   in the changePassword, verifyUserIDPwd, or the logon APIs.     *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   const char * systemName - input                                *)
(*       A pointer to an ASCIIZ string containing the name of the   *)
(*       AS/400 system.                                             *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle supplied is not       *)
(*                        valid.                                    *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_INVALID_PARAMETER - One of the parameters specified is     *)
(*                           invalid.                               *)
(*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   *)
(*                           to allocate temporary buffer.          *)
(*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE *)
(*                                        characters have no        *)
(*                                        representation in the     *)
(*                                        codepage being used.      *)
(*   CWB_API_ERROR - General API failure.                           *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   None                                                           *)
(*                                                                  *)
(********************************************************************)

function cwbSY_SetSys(
securityHandle: CWBSY_SECURITYHANDLE;
const systemName: PChar
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_SetSysA(
securityHandle: CWBSY_SECURITYHANDLE;
var systemName: AnsiString
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_SetSysW(
securityHandle: CWBSY_SECURITYHANDLE;
var systemName: WideString
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_VerifyUserIDPwd                                          *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   Verifies the user ID and password are valid for the given      *)
(*   system.                                                        *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   const char * userID - input                                    *)
(*       A pointer to an ASCIIZ string which contains the user ID.  *)
(*       The maximum length is 10 bytes + 1 byte                    *)
(*       for the NULL terminator.                                   *)
(*                                                                  *)
(*   const char * password - input                                  *)
(*       A pointer to an ASCIIZ string which contains the current   *)
(*       password.  The maximum length is 10 bytes + 1 byte for the *)
(*       NULL terminator.                                           *)
(*                                                                  *)
(*   cwbSV_ErrHandle errorHandle - output                           *)
(*     Any returned messages will be written to this object.  It    *)
(*     is created with the cwbSV_CreateErrHandle API.  The          *)
(*     messages may be retrieved through the cwbSV_GetErrText API.  *)
(*     If the parameter is set to zero, no messages will be         *)
(*     retrieved.                                                   *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle is not valid.         *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_COMMUNICATIONS_ERROR - A communication error occurred      *)
(*                              when attempting to contact the      *)
(*                              system.                             *)
(*   CWBSY_SYSTEM_NOT_CONFIGURED - The system has not been          *)
(*                                 configured.                      *)
(*   CWBSY_UNKNOWN_USERID - The supplied user ID is not             *)
(*                          known to this system.                   *)
(*   CWBSY_WRONG_PASSWORD - Password is not correct.                *)
(*   CWBSY_PASSWORD_EXPIRED - Password has expired.                 *)
(*   CWBSY_USER_PROFILE_DISABLED - The user ID has been disabled.   *)
(*   CWBSY_INVALID_PASSWORD - One or more characters in the         *)
(*                            password is invalid or the password   *)
(*                            is too long.                          *)
(*   CWBSY_INVALID_USERID - One or more characters in the user ID   *)
(*                          is invalid or the user ID is too long.  *)
(*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   *)
(*                           to allocate temporary buffer.          *)
(*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE *)
(*                                        characters have no        *)
(*                                        representation in the     *)
(*                                        codepage being used.      *)
(*   CWB_API_ERROR - General API failure.                           *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   The system name must set prior to calling this API by using    *)
(*   the cwbSY_SetSys API.                                          *)
(*                                                                  *)
(********************************************************************)

function cwbSY_VerifyUserIDPwd(
securityHandle: CWBSY_SECURITYHANDLE;
const userID: PChar;
const password: PChar;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_VerifyUserIDPwdA(
securityHandle: CWBSY_SECURITYHANDLE;
var userID: AnsiString;
var password: AnsiString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_VerifyUserIDPwdW(
securityHandle: CWBSY_SECURITYHANDLE;
var userID: WideString;
var password: WideString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

(********************************************************************)
(*                                                                  *)
(* API:                                                             *)
(*   cwbSY_LogonUser                                                *)
(*                                                                  *)
(* Purpose:                                                         *)
(*   The API validates the supplied user ID and password without    *)
(*   presenting a sign-on prompt. If they are valid, the            *)
(*   information is stored and subsequent sign-ons and requests for *)
(*   other functions are not prompted for.                          *)
(*                                                                  *)
(*   Note: This API differs from cwbSY_Logon() in that a sign-on    *)
(*         prompt will not be presented because the user ID and     *)
(*         password information is being passed in on the call.     *)
(*         Also, any message dialogs (e.g. password expired) will   *)
(*         not be displayed. The return code will be set to         *)
(*         indicate these type of conditions.                       *)
(*                                                                  *)
(*   This API can be used to ensure that subsequent API function    *)
(*   calls in your program that establish connections to an AS/400  *)
(*   system will not prompt for sign-on information.                *)
(*                                                                  *)
(* Parameters:                                                      *)
(*   cwbSY_SecurityHandle securityHandle - input                    *)
(*       A valid handle to a security object.  The handle           *)
(*       is obtained using cwbSY_CreateSecurityObj.                 *)
(*                                                                  *)
(*   const char * userID - input                                    *)
(*       A pointer to an ASCIIZ string which contains the user ID.  *)
(*       The maximum length is 10 bytes + 1 byte                    *)
(*       for the NULL terminator.                                   *)
(*                                                                  *)
(*   const char * password - input                                  *)
(*       A pointer to an ASCIIZ string which contains the current   *)
(*       password.  The maximum length is 10 bytes + 1 byte for the *)
(*       NULL terminator.                                           *)
(*                                                                  *)
(*   cwbSV_ErrHandle errorHandle - output                           *)
(*     Any returned messages will be written to this object.  It    *)
(*     is created with the cwbSV_CreateErrHandle API.  The          *)
(*     messages may be retrieved through the cwbSV_GetErrText API.  *)
(*     If the parameter is set to zero, no messages will be         *)
(*     retrieved.                                                   *)
(*                                                                  *)
(* Return Codes:                                                    *)
(*   The following list shows common return values.                 *)
(*                                                                  *)
(*   CWB_OK - Successful completion.                                *)
(*   CWB_INVALID_HANDLE - The security handle is not valid.         *)
(*   CWB_INVALID_POINTER - A pointer supplied to the API is not     *)
(*                         valid.                                   *)
(*   CWB_COMMUNICATIONS_ERROR - A communication error occurred      *)
(*                              when attempting to contact the      *)
(*                              system.                             *)
(*   CWBSY_SYSTEM_NOT_CONFIGURED - The system has not been          *)
(*                                 configured.                      *)
(*   CWBSY_UNKNOWN_USERID - The supplied user ID is not             *)
(*                          known to this system.                   *)
(*   CWBSY_WRONG_PASSWORD - Password is not correct.                *)
(*   CWBSY_PASSWORD_EXPIRED - Password has expired.                 *)
(*   CWBSY_LAST_INVALID_PASSWORD - The next invalid password        *)
(*                                 will disable the user profile.   *)
(*   CWBSY_USER_PROFILE_DISABLED - The user ID has been disabled.   *)
(*   CWBSY_INVALID_PASSWORD - One or more characters in the         *)
(*                            password is invalid or the password   *)
(*                            is too long.                          *)
(*   CWBSY_INVALID_USERID - One or more characters in the user ID   *)
(*                          is invalid or the user ID is too long.  *)
(*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   *)
(*                           to allocate temporary buffer.          *)
(*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE *)
(*                                        characters have no        *)
(*                                        representation in the     *)
(*                                        codepage being used.      *)
(*   CWB_API_ERROR - General API failure.                           *)
(*                                                                  *)
(* Usage Notes:                                                     *)
(*   The system name must set prior to calling this API by using    *)
(*   the cwbSY_SetSys API.                                          *)
(*                                                                  *)
(********************************************************************)

function cwbSY_LogonUser(
securityHandle: CWBSY_SECURITYHANDLE;
const userID: PChar;
const password: PChar;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_LogonUserA(
securityHandle: CWBSY_SECURITYHANDLE;
var userID: AnsiString;
var password: AnsiString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

function cwbSY_LogonUserW(
securityHandle: CWBSY_SECURITYHANDLE;
var userID: WideString;
var password: WideString;
errorHandle: CWBSV_ERRHANDLE
): Word; stdcall; external 'cwbsy.dll';

implementation

end.
